@@ -6,8 +6,8 @@
 
     Last commit info:
     ~~~~~~~~~~~~~~~~~
-    $LastChangedDate: 2009-05-15 15:44:48 +0200 (Fr, 15 Mai 2009) $
-    $Rev: 34 $
+    $LastChangedDate: 2009-05-16 11:21:38 +0200 (Sa, 16 Mai 2009) $
+    $Rev: 36 $
     $Author: google.groups@jensdiemer.de $
 
     :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
@@ -134,6 +134,11 @@ class TestHtml2CreoleMarkup(BaseCreoleTest):
         """, """
             <p>copy&paste</p>
         """)
+        self.assertCreole(r"""
+            [[/url/|Search & Destroy]]
+        """, """
+            <a href="/url/">Search & Destroy</a>
+        """)
 
     def test_tbody_table(self):
         self.assertCreole(r"""
@@ -173,8 +178,17 @@ class TestHtml2CreoleMarkup(BaseCreoleTest):
         """)
 
     #--------------------------------------------------------------------------
+    # TODOs:
+    
+    def test_format_in_a_text(self):
+        """ http://code.google.com/p/python-creole/issues/detail?id=4 """
+        self.assertCreole(r"""
+            **[[/url/|title]]**
+        """, """
+            <a href="/url/"><strong>title</strong></a>
+        """)
+
 
-#
 #    def test_links(self):
 #        self.assertCreole(r"""
 #            test link: '[[internal links|link A]]' 1 and
